@@ -2,9 +2,9 @@ from foxify_cli.logger import error, info
 from fuzzywuzzy import fuzz, process
 from foxify_cli.core.methods import (
     clear, backup, clear_backup,
-    apply, themes, version,
+    apply, themes, getversion,
     helpmenu, configpath, information,
-    update
+    update, restore
 )
 
 class ArgParser:
@@ -57,10 +57,12 @@ class ArgParser:
                     exit(1)
                 theme_name = self.args[self.args.index('apply') + 1]
                 apply(theme_name)
+            if "restore" == arg:
+                restore()
             if "themes" == arg:
                 themes()
             if "version" == arg:
-                version()
+                getversion()
             if "help" == arg:
                 helpmenu()
             if "config" == arg:
