@@ -1,4 +1,5 @@
 from foxify_cli.config.startup import CONFIG_PATH
+from foxify_cli import version
 from ruamel.yaml import YAML
 from foxify_cli.logger import info, success, warning, error
 from tqdm import tqdm
@@ -21,8 +22,8 @@ def check_for_process(process_name):
             pass
     return False
 
-def version():
-    info("Foxify v1.0.1")
+def getversion():
+    info("Foxify v" + version)
     exit(0)
     
 def helpmenu():
@@ -112,9 +113,9 @@ def information():
 ██╔══╝  ██║   ██║ ██╔██╗ ██║██╔══╝    ╚██╔╝  
 ██║     ╚██████╔╝██╔╝ ██╗██║██║        ██║   
 ╚═╝      ╚═════╝ ╚═╝  ╚═╝╚═╝╚═╝        ╚═╝""")
-    print("Version: 1.0.1")
-    print("Created by Max Bridgland <https://github.com/M4cs>")
-    print("Find More FirefoxCSS Themes At These Links:")
+    info("Version:", version)
+    info("Created by Max Bridgland <https://github.com/M4cs>")
+    info("Find More FirefoxCSS Themes At These Links:")
     print("https://www.reddit.com/r/FirefoxCSS/")
     print("https://github.com/Timvde/UserChrome-Tweaks")
     print("https://github.com/MrOtherGuy/firefox-csshacks")
@@ -139,12 +140,13 @@ def clear_backup():
         warning("Skipping Backup Clearing")
         
 def update():
-    res = requests.get('https://raw.githubusercontent.com/M4cs/foxify-cli/master/version').content
     with open(CONFIG_PATH + '/config', 'r') as f:
         yaml = YAML(typ='safe')
         config = yaml.load(f)
-        if config['version'] != res:
-            info("Update Available! Run 'pip3 install --upgrade foxify-cli' to Update to Version: " + res)
+        if not config['check_for_updates']:
+            res = requests.get('https://raw.githubusercontent.com/M4cs/foxify-cli/master/version').text
+            if config['version'] != res:
+                info("Update Available! Run 'pip3 install --upgrade foxify-cli' to Update to Version: " + res)
         
 
 def restore():
@@ -163,14 +165,14 @@ def restore():
                     os.remove(os.path.join(os.path.realpath(profile_dir + '/chrome'), file))
             info("Starting Restore Process...")
             for file in tqdm(os.listdir(os.path.realpath(profile_dir + '/chrome_backup')), ncols=35, smoothing=True, bar_format=Fore.LIGHTCYAN_EX + Style.BRIGHT + "[PROGRESS] " + Fore.RESET + Style.RESET_ALL + '{n_fmt}/{total_fmt} | {bar}'):
-                if os.path.isdir(os.path.join(os.path.realpath(CONFIG_PATH + '/chrome_backup'), file)):
-                    shutil.copytree(os.path.join(os.path.realpath(CONFIG_PATH + '/chrome_backup'), file), os.path.realpath(profile_dir + '/chrome' + file))
+                if os.path.isdir(os.path.join(os.path.realpath(profile_dir + '/chrome_backup'), file)):
+                    shutil.copytree(os.path.join(os.path.realpath(profile_dir + '/chrome_backup'), file), os.path.realpath(profile_dir + '/chrome/' + file))
                 else:
-                    shutil.copy(os.path.join(os.path.realpath(CONFIG_PATH + '/chrome_backup'), file), os.path.realpath(profile_dir + '/chrome' + file))
+                    shutil.copy(os.path.join(os.path.realpath(profile_dir + '/chrome_backup'), file), os.path.realpath(profile_dir + '/chrome/' + file))
             success("Completed Restore Process, Killing Firefox!")
             if check_for_process("firefox"):
                 if platform == "linux" or platform == "linux2" or platform == "darwin":
-                    subprocess.call(['kill', '-9', '$(ps -x | grep firefox)'], stdout=FNULL, stderr=subprocess.STDOUT)
+                    subprocess.call(['killall', 'firefox'], stdout=FNULL, stderr=subprocess.STDOUT)
                 elif platform == "win32":
                     subprocess.call(['taskkill', '/f', '/im', 'firefox.exe'], stdout=FNULL, stderr=subprocess.STDOUT)
                 success("Closed Firefox! Re-open to see your new theme!")
@@ -221,7 +223,7 @@ def clear():
     info("Attempting to Kill Firefox...")
     if check_for_process("firefox"):
         if platform == "linux" or platform == "linux2" or platform == "darwin":
-            subprocess.call(['kill', '-9', '$(ps -x | grep firefox)'], stdout=FNULL, stderr=subprocess.STDOUT)
+            subprocess.call(['killall', 'firefox'], stdout=FNULL, stderr=subprocess.STDOUT)
         elif platform == "win32":
             subprocess.call(['taskkill', '/f', '/im', 'firefox.exe'], stdout=FNULL, stderr=subprocess.STDOUT)
         success("Closed Firefox!")
@@ -256,7 +258,7 @@ def apply(theme_name):
         success("Applied Theme Closing Firefox...")
         if check_for_process("firefox"):
             if platform == "linux" or platform == "linux2" or platform == "darwin":
-                subprocess.call(['kill', '-9', '$(ps -x | grep firefox)'], stdout=FNULL, stderr=subprocess.STDOUT)
+                subprocess.call(['killall', 'firefox'], stdout=FNULL, stderr=subprocess.STDOUT)
             elif platform == "win32":
                 subprocess.call(['taskkill', '/f', '/im', 'firefox.exe'], stdout=FNULL, stderr=subprocess.STDOUT)
             success("Closed Firefox! Re-open to see your new theme!")
